# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Union
from pydantic import BaseModel, Field, StrictInt, confloat, conint
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.mtu_period import MtuPeriod

class AggregatedAllocatedAuction(BaseModel):
    """
    AggregatedAllocatedAuction
    """
    timescale: AuctionTimescale = Field(...)
    auction_count: conint(strict=True, ge=0) = Field(..., alias="auctionCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    product_type_count: conint(strict=True, ge=0) = Field(..., alias="productTypeCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    border_direction: BorderDirection = Field(..., alias="borderDirection")
    delivery_period: MtuPeriod = Field(..., alias="deliveryPeriod")
    participant_requested_count: conint(strict=True, ge=0) = Field(..., alias="participantRequestedCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    participant_allocated_count: conint(strict=True, ge=0) = Field(..., alias="participantAllocatedCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    offered_capacity: StrictInt = Field(..., alias="offeredCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    total_requested_capacity: StrictInt = Field(..., alias="totalRequestedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    total_allocated_capacity: StrictInt = Field(..., alias="totalAllocatedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    average_clearing_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="averageClearingPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    __properties = ["timescale", "auctionCount", "productTypeCount", "borderDirection", "deliveryPeriod", "participantRequestedCount", "participantAllocatedCount", "offeredCapacity", "totalRequestedCapacity", "totalAllocatedCapacity", "averageClearingPrice"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AggregatedAllocatedAuction:
        """Create an instance of AggregatedAllocatedAuction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of delivery_period
        if self.delivery_period:
            _dict['deliveryPeriod'] = self.delivery_period.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AggregatedAllocatedAuction:
        """Create an instance of AggregatedAllocatedAuction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AggregatedAllocatedAuction.parse_obj(obj)

        _obj = AggregatedAllocatedAuction.parse_obj({
            "timescale": obj.get("timescale"),
            "auction_count": obj.get("auctionCount"),
            "product_type_count": obj.get("productTypeCount"),
            "border_direction": obj.get("borderDirection"),
            "delivery_period": MtuPeriod.from_dict(obj.get("deliveryPeriod")) if obj.get("deliveryPeriod") is not None else None,
            "participant_requested_count": obj.get("participantRequestedCount"),
            "participant_allocated_count": obj.get("participantAllocatedCount"),
            "offered_capacity": obj.get("offeredCapacity"),
            "total_requested_capacity": obj.get("totalRequestedCapacity"),
            "total_allocated_capacity": obj.get("totalAllocatedCapacity"),
            "average_clearing_price": obj.get("averageClearingPrice")
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class MessageType(str, Enum):
    """
    MessageType
    """

    """
    allowed enum values
    """
    AUCTION = 'AUCTION'
    BPP = 'BPP'
    BUY_NOW_AUCTION = 'BUY_NOW_AUCTION'
    FINANCE = 'FINANCE'
    JAO = 'JAO'
    MANUAL_MESSAGE = 'MANUAL_MESSAGE'
    NOMINATION = 'NOMINATION'
    OPERATIONAL_DATAFLOW = 'OPERATIONAL_DATAFLOW'
    OPERATIONAL_PROCESS = 'OPERATIONAL_PROCESS'
    PARTICIPANT_CONFIGURATION = 'PARTICIPANT_CONFIGURATION'
    PARTICIPANT_PROCESS = 'PARTICIPANT_PROCESS'
    PLANNED_OUTAGE = 'PLANNED_OUTAGE'
    PROCESS = 'PROCESS'
    SECONDARY_MARKET = 'SECONDARY_MARKET'
    TRANSPARENCY_DATAFLOW = 'TRANSPARENCY_DATAFLOW'
    UNPLANNED_OUTAGE = 'UNPLANNED_OUTAGE'

    @classmethod
    def from_json(cls, json_str: str) -> MessageType:
        """Create an instance of MessageType from a JSON string"""
        return MessageType(json.loads(json_str))





# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field
from empire_platform_api_public_client.models.invoice_action_type import InvoiceActionType
from empire_platform_api_public_client.models.invoice_participant_details import InvoiceParticipantDetails

class InvoiceHistory(BaseModel):
    """
    Participant basic information
    """
    user: Optional[InvoiceParticipantDetails] = None
    action: InvoiceActionType = Field(...)
    actioned_at: datetime = Field(..., alias="actionedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["user", "action", "actionedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InvoiceHistory:
        """Create an instance of InvoiceHistory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InvoiceHistory:
        """Create an instance of InvoiceHistory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return InvoiceHistory.parse_obj(obj)

        _obj = InvoiceHistory.parse_obj({
            "user": InvoiceParticipantDetails.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "action": obj.get("action"),
            "actioned_at": obj.get("actionedAt")
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr, conint

class Attachment(BaseModel):
    """
    Represents an attachment (file) stored in a persistent way  - `fileName`: Name of the attachment including extension, example: `attachment.xls` - `fileSize`: Size of the file in bytes, example: `2338` - `mimeType`: Standard MIME type of attachment, example: `application/vnd.ms-excel` - `url`: Address from where the binary file can be downloaded, example: `https://example.com/document.xls` 
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    file_name: StrictStr = Field(..., alias="fileName")
    file_size: conint(strict=True, ge=0) = Field(..., alias="fileSize", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    mime_type: StrictStr = Field(..., alias="mimeType")
    url: StrictStr = Field(...)
    __properties = ["id", "fileName", "fileSize", "mimeType", "url"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Attachment:
        """Create an instance of Attachment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Attachment:
        """Create an instance of Attachment from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Attachment.parse_obj(obj)

        _obj = Attachment.parse_obj({
            "id": obj.get("id"),
            "file_name": obj.get("fileName"),
            "file_size": obj.get("fileSize"),
            "mime_type": obj.get("mimeType"),
            "url": obj.get("url")
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, conlist
from empire_platform_api_public_client.models.bid_value import BidValue

class UpdateLongTermDefaultBidRequest(BaseModel):
    """
    UpdateLongTermDefaultBidRequest
    """
    delivery_period_start: datetime = Field(..., alias="deliveryPeriodStart", description="The first moment (inclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    delivery_period_end: Optional[datetime] = Field(None, alias="deliveryPeriodEnd", description="The last moment (exclusive) of an MTU period  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute MTU start point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format - only with `XX:00:00`, `XX:15:00`, `XX:30:00` and `XX:45:00` time parts are valid values (depending on MTU size) ")
    validity_period_start: datetime = Field(..., alias="validityPeriodStart", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    validity_period_end: Optional[datetime] = Field(None, alias="validityPeriodEnd", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    bids: conlist(BidValue) = Field(...)
    __properties = ["deliveryPeriodStart", "deliveryPeriodEnd", "validityPeriodStart", "validityPeriodEnd", "bids"]

    # @validator('delivery_period_start')
    def delivery_period_start_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^.*T.*:(00|15|30|45):00(\.0+)?(Z|\+.*)$", value):
            raise ValueError(r"must validate the regular expression /^.*T.*:(00|15|30|45):00(\.0+)?(Z|\+.*)$/")
        return value

    # @validator('delivery_period_end')
    def delivery_period_end_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^.*T.*:(00|15|30|45):00(\.0+)?(Z|\+.*)$", value):
            raise ValueError(r"must validate the regular expression /^.*T.*:(00|15|30|45):00(\.0+)?(Z|\+.*)$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateLongTermDefaultBidRequest:
        """Create an instance of UpdateLongTermDefaultBidRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in bids (list)
        _items = []
        if self.bids:
            for _item in self.bids:
                if _item:
                    _items.append(_item.to_dict())
            _dict['bids'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateLongTermDefaultBidRequest:
        """Create an instance of UpdateLongTermDefaultBidRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateLongTermDefaultBidRequest.parse_obj(obj)

        _obj = UpdateLongTermDefaultBidRequest.parse_obj({
            "delivery_period_start": obj.get("deliveryPeriodStart"),
            "delivery_period_end": obj.get("deliveryPeriodEnd"),
            "validity_period_start": obj.get("validityPeriodStart"),
            "validity_period_end": obj.get("validityPeriodEnd"),
            "bids": [BidValue.from_dict(_item) for _item in obj.get("bids")] if obj.get("bids") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SageCode(str, Enum):
    """
    SageCode
    """

    """
    allowed enum values
    """
    NL_GB_EXPLICIT_ANNUAL_AUCTIONS = 'NL_GB_EXPLICIT_ANNUAL_AUCTIONS'
    NL_GB_EXPLICIT_SEASONAL_AUCTIONS = 'NL_GB_EXPLICIT_SEASONAL_AUCTIONS'
    NL_GB_EXPLICIT_MULTI_ANNUAL_AUCTIONS = 'NL_GB_EXPLICIT_MULTI_ANNUAL_AUCTIONS'
    NL_GB_EXPLICIT_QUARTERLY_AUCTIONS = 'NL_GB_EXPLICIT_QUARTERLY_AUCTIONS'
    NL_GB_EXPLICIT_MONTHLY_AUCTIONS = 'NL_GB_EXPLICIT_MONTHLY_AUCTIONS'
    NL_GB_EXPLICIT_WEEKLY_AUCTIONS = 'NL_GB_EXPLICIT_WEEKLY_AUCTIONS'
    NL_GB_EXPLICIT_MULTI_DAY_AUCTIONS = 'NL_GB_EXPLICIT_MULTI_DAY_AUCTIONS'
    NL_GB_EXPLICIT_LONG_WEEKEND_AUCTIONS = 'NL_GB_EXPLICIT_LONG_WEEKEND_AUCTIONS'
    NL_GB_EXPLICIT_WEEKEND_AUCTIONS = 'NL_GB_EXPLICIT_WEEKEND_AUCTIONS'
    NL_GB_EXPLICIT_INTRA_DAY_AUCTIONS = 'NL_GB_EXPLICIT_INTRA_DAY_AUCTIONS'
    NL_GB_EXPLICIT_DAY_AHEAD_AUCTIONS = 'NL_GB_EXPLICIT_DAY_AHEAD_AUCTIONS'
    NL_GB_EXPLICIT_BUY_NOW_DAY_AHEAD = 'NL_GB_EXPLICIT_BUY_NOW_DAY_AHEAD'
    NL_GB_EXPLICIT_BUY_NOW_INTRA_DAY = 'NL_GB_EXPLICIT_BUY_NOW_INTRA_DAY'
    NL_GB_EXPLICIT_RETURN_ANNUAL_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_ANNUAL_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_SEASONAL_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_SEASONAL_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_MULTI_ANNUAL_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_MULTI_ANNUAL_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_QUARTERLY_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_QUARTERLY_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_MONTHLY_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_MONTHLY_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_WEEKLY_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_WEEKLY_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_MULTI_DAY_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_MULTI_DAY_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_LONG_WEEKEND_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_LONG_WEEKEND_AUCTIONS'
    NL_GB_EXPLICIT_RETURN_WEEKEND_AUCTIONS = 'NL_GB_EXPLICIT_RETURN_WEEKEND_AUCTIONS'
    NL_GB_EXPLICIT_CURTAILMENT_LONG_TERM = 'NL_GB_EXPLICIT_CURTAILMENT_LONG_TERM'
    NL_GB_EXPLICIT_CURTAILMENT_INTRA_DAY = 'NL_GB_EXPLICIT_CURTAILMENT_INTRA_DAY'
    NL_GB_EXPLICIT_CURTAILMENT_DAY_AHEAD = 'NL_GB_EXPLICIT_CURTAILMENT_DAY_AHEAD'
    NL_GB_UIOSI_COMPENSATIONS_LONG_TERM = 'NL_GB_UIOSI_COMPENSATIONS_LONG_TERM'
    NL_GB_UIOSI_COMPENSATIONS_DAY_AHEAD = 'NL_GB_UIOSI_COMPENSATIONS_DAY_AHEAD'
    GB_NL_EXPLICIT_ANNUAL_AUCTIONS = 'GB_NL_EXPLICIT_ANNUAL_AUCTIONS'
    GB_NL_EXPLICIT_SEASONAL_AUCTIONS = 'GB_NL_EXPLICIT_SEASONAL_AUCTIONS'
    GB_NL_EXPLICIT_MULTI_ANNUAL_AUCTIONS = 'GB_NL_EXPLICIT_MULTI_ANNUAL_AUCTIONS'
    GB_NL_EXPLICIT_QUARTERLY_AUCTIONS = 'GB_NL_EXPLICIT_QUARTERLY_AUCTIONS'
    GB_NL_EXPLICIT_MONTHLY_AUCTIONS = 'GB_NL_EXPLICIT_MONTHLY_AUCTIONS'
    GB_NL_EXPLICIT_WEEKLY_AUCTIONS = 'GB_NL_EXPLICIT_WEEKLY_AUCTIONS'
    GB_NL_EXPLICIT_MULTI_DAY_AUCTIONS = 'GB_NL_EXPLICIT_MULTI_DAY_AUCTIONS'
    GB_NL_EXPLICIT_LONG_WEEKEND_AUCTIONS = 'GB_NL_EXPLICIT_LONG_WEEKEND_AUCTIONS'
    GB_NL_EXPLICIT_WEEKEND_AUCTIONS = 'GB_NL_EXPLICIT_WEEKEND_AUCTIONS'
    GB_NL_EXPLICIT_INTRA_DAY_AUCTIONS = 'GB_NL_EXPLICIT_INTRA_DAY_AUCTIONS'
    GB_NL_EXPLICIT_DAY_AHEAD_AUCTIONS = 'GB_NL_EXPLICIT_DAY_AHEAD_AUCTIONS'
    GB_NL_EXPLICIT_BUY_NOW_DAY_AHEAD = 'GB_NL_EXPLICIT_BUY_NOW_DAY_AHEAD'
    GB_NL_EXPLICIT_BUY_NOW_INTRA_DAY = 'GB_NL_EXPLICIT_BUY_NOW_INTRA_DAY'
    GB_NL_EXPLICIT_RETURN_ANNUAL_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_ANNUAL_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_SEASONAL_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_SEASONAL_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_MULTI_ANNUAL_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_MULTI_ANNUAL_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_QUARTERLY_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_QUARTERLY_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_MONTHLY_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_MONTHLY_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_WEEKLY_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_WEEKLY_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_MULTI_DAY_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_MULTI_DAY_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_LONG_WEEKEND_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_LONG_WEEKEND_AUCTIONS'
    GB_NL_EXPLICIT_RETURN_WEEKEND_AUCTIONS = 'GB_NL_EXPLICIT_RETURN_WEEKEND_AUCTIONS'
    GB_NL_EXPLICIT_CURTAILMENT_LONG_TERM = 'GB_NL_EXPLICIT_CURTAILMENT_LONG_TERM'
    GB_NL_EXPLICIT_CURTAILMENT_INTRA_DAY = 'GB_NL_EXPLICIT_CURTAILMENT_INTRA_DAY'
    GB_NL_EXPLICIT_CURTAILMENT_DAY_AHEAD = 'GB_NL_EXPLICIT_CURTAILMENT_DAY_AHEAD'
    GB_NL_UIOSI_COMPENSATIONS_LONG_TERM = 'GB_NL_UIOSI_COMPENSATIONS_LONG_TERM'
    GB_NL_UIOSI_COMPENSATIONS_DAY_AHEAD = 'GB_NL_UIOSI_COMPENSATIONS_DAY_AHEAD'

    @classmethod
    def from_json(cls, json_str: str) -> SageCode:
        """Create an instance of SageCode from a JSON string"""
        return SageCode(json.loads(json_str))





# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry import SecondaryMarketNoticeboardEntry  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSecondaryMarketNoticeboardEntry(unittest.TestCase):
    """SecondaryMarketNoticeboardEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecondaryMarketNoticeboardEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketNoticeboardEntry`
        """
        model = empire_platform_api_public_client.models.secondary_market_noticeboard_entry.SecondaryMarketNoticeboardEntry()  # noqa: E501
        if include_optional :
            return SecondaryMarketNoticeboardEntry(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                type = 'BUY', 
                delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                    start = 'Tue Jan 04 00:00:00 UTC 2022', 
                    end = 'Tue Jan 04 00:00:00 UTC 2022', ), 
                timescale = 'LONG_TERM', 
                direction = 'GB_NL', 
                notice_capacity = 56, 
                notice_price = 1.337, 
                posted_at = '2022-01-04T00:00Z', 
                status = 'ACTIVE', 
                expires_at = '2022-01-04T00:00Z', 
                is_own = True
            )
        else :
            return SecondaryMarketNoticeboardEntry(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                type = 'BUY',
                delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                    start = 'Tue Jan 04 00:00:00 UTC 2022', 
                    end = 'Tue Jan 04 00:00:00 UTC 2022', ),
                timescale = 'LONG_TERM',
                direction = 'GB_NL',
                posted_at = '2022-01-04T00:00Z',
                status = 'ACTIVE',
                expires_at = '2022-01-04T00:00Z',
        )
        """

    def testSecondaryMarketNoticeboardEntry(self):
        """Test SecondaryMarketNoticeboardEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, constr, validator
from empire_platform_api_public_client.models.organisation_market_settings_gb_nomination_settings import OrganisationMarketSettingsGbNominationSettings
from empire_platform_api_public_client.models.organisation_market_settings_nl_nomination_settings import OrganisationMarketSettingsNlNominationSettings

class OrganisationMarketSettings(BaseModel):
    """
    OrganisationMarketSettings
    """
    eic_code: constr(strict=True) = Field(..., alias="eicCode")
    gb_nomination_settings: OrganisationMarketSettingsGbNominationSettings = Field(..., alias="gbNominationSettings")
    nl_nomination_settings: OrganisationMarketSettingsNlNominationSettings = Field(..., alias="nlNominationSettings")
    __properties = ["eicCode", "gbNominationSettings", "nlNominationSettings"]

    # @validator('eic_code')
    def eic_code_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^([0-9]|[A-Z]|-){16}$", value):
            raise ValueError(r"must validate the regular expression /^([0-9]|[A-Z]|-){16}$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OrganisationMarketSettings:
        """Create an instance of OrganisationMarketSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gb_nomination_settings
        if self.gb_nomination_settings:
            _dict['gbNominationSettings'] = self.gb_nomination_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of nl_nomination_settings
        if self.nl_nomination_settings:
            _dict['nlNominationSettings'] = self.nl_nomination_settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OrganisationMarketSettings:
        """Create an instance of OrganisationMarketSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OrganisationMarketSettings.parse_obj(obj)

        _obj = OrganisationMarketSettings.parse_obj({
            "eic_code": obj.get("eicCode"),
            "gb_nomination_settings": OrganisationMarketSettingsGbNominationSettings.from_dict(obj.get("gbNominationSettings")) if obj.get("gbNominationSettings") is not None else None,
            "nl_nomination_settings": OrganisationMarketSettingsNlNominationSettings.from_dict(obj.get("nlNominationSettings")) if obj.get("nlNominationSettings") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from empire_platform_api_public_client.models.auction_allocation_resolution import AuctionAllocationResolution
from empire_platform_api_public_client.models.auction_process_steps_absolute import AuctionProcessStepsAbsolute
from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu import DayAheadOrIntraDayAuctionMtu
from empire_platform_api_public_client.models.mtu_period import MtuPeriod
from empire_platform_api_public_client.models.mtu_size import MtuSize
from empire_platform_api_public_client.models.public_auction_status import PublicAuctionStatus

class PublicIntraDayAuction(BaseModel):
    """
    PublicIntraDayAuction
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    name: StrictStr = Field(..., description="Human readable name")
    display_id: StrictStr = Field(..., alias="displayId", description="Generated display identifier")
    product_type: AuctionProductType = Field(..., alias="productType")
    border_direction: BorderDirection = Field(..., alias="borderDirection")
    status: PublicAuctionStatus = Field(...)
    processing: StrictBool = Field(...)
    delivery_period: MtuPeriod = Field(..., alias="deliveryPeriod")
    allocation_mtu_size: MtuSize = Field(..., alias="allocationMtuSize")
    allocation_resolution: AuctionAllocationResolution = Field(..., alias="allocationResolution")
    process_steps: AuctionProcessStepsAbsolute = Field(..., alias="processSteps")
    mtus: conlist(DayAheadOrIntraDayAuctionMtu) = Field(...)
    __properties = ["id", "name", "displayId", "productType", "borderDirection", "status", "processing", "deliveryPeriod", "allocationMtuSize", "allocationResolution", "processSteps", "mtus"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PublicIntraDayAuction:
        """Create an instance of PublicIntraDayAuction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of delivery_period
        if self.delivery_period:
            _dict['deliveryPeriod'] = self.delivery_period.to_dict()
        # override the default output from pydantic by calling `to_dict()` of process_steps
        if self.process_steps:
            _dict['processSteps'] = self.process_steps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in mtus (list)
        _items = []
        if self.mtus:
            for _item in self.mtus:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mtus'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PublicIntraDayAuction:
        """Create an instance of PublicIntraDayAuction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PublicIntraDayAuction.parse_obj(obj)

        _obj = PublicIntraDayAuction.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "display_id": obj.get("displayId"),
            "product_type": obj.get("productType"),
            "border_direction": obj.get("borderDirection"),
            "status": obj.get("status"),
            "processing": obj.get("processing"),
            "delivery_period": MtuPeriod.from_dict(obj.get("deliveryPeriod")) if obj.get("deliveryPeriod") is not None else None,
            "allocation_mtu_size": obj.get("allocationMtuSize"),
            "allocation_resolution": obj.get("allocationResolution"),
            "process_steps": AuctionProcessStepsAbsolute.from_dict(obj.get("processSteps")) if obj.get("processSteps") is not None else None,
            "mtus": [DayAheadOrIntraDayAuctionMtu.from_dict(_item) for _item in obj.get("mtus")] if obj.get("mtus") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class LongTermAuctionBidSortBy(str, Enum):
    """
    LongTermAuctionBidSortBy
    """

    """
    allowed enum values
    """
    BID_PRICE_ASC = 'BID_PRICE_ASC'
    BID_PRICE_DESC = 'BID_PRICE_DESC'
    CAPACITY_ASC = 'CAPACITY_ASC'
    CAPACITY_DESC = 'CAPACITY_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> LongTermAuctionBidSortBy:
        """Create an instance of LongTermAuctionBidSortBy from a JSON string"""
        return LongTermAuctionBidSortBy(json.loads(json_str))


